==> qtjambi-quick-debuginfo-macos-5.15.18.jar: sources/QtJambiQuick/QSGRectangleNode_shell.h <==
#ifndef QSGRECTANGLENODE_SHELL_H
#define QSGRECTANGLENODE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qsgrectanglenode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qrect.h>
#include <QtGui/qcolor.h>
#include <QtGui/qmatrix4x4.h>
#include <QtQuick/qsggeometry.h>
#include <QtQuick/qsgmaterial.h>
#include <QtQuick/qsgnode.h>
#include <QtJambi/RegistryAPI>


class QSGRectangleNode_shell : public QSGRectangleNode, public QtJambiShellInterface
{
public:
    QSGRectangleNode_shell();
    ~QSGRectangleNode_shell() override;

    QColor color() const override;
    bool isSubtreeBlocked() const override;
    void preprocess() override;
    QRectF rect() const override;
    void setColor(const QColor& color0) override;
    void setRect(const QRectF& rect0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSGRectangleNode_access : public QSGRectangleNode
{
    jobject __qt_color(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_rect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setColor_cref_QColor(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID color0);
    void __qt_setRect_cref_QRectF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0);
};

#endif // QSGRECTANGLENODE_SHELL_H

==> qtjambi-quick-debuginfo-macos-6.5.6.jar: sources/QtJambiQuick/QSGRectangleNode_shell.h <==
#ifndef QSGRECTANGLENODE_SHELL_H
#define QSGRECTANGLENODE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qsgrectanglenode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qrect.h>
#include <QtGui/qcolor.h>
#include <QtGui/qmatrix4x4.h>
#include <QtQuick/qsggeometry.h>
#include <QtQuick/qsgmaterial.h>
#include <QtQuick/qsgnode.h>
#include <QtJambi/RegistryAPI>


class QSGRectangleNode_shell : public QSGRectangleNode, public QtJambiShellInterface
{
public:
    QSGRectangleNode_shell();
    ~QSGRectangleNode_shell() override;

    QColor color() const override;
    bool isSubtreeBlocked() const override;
    void preprocess() override;
    QRectF rect() const override;
    void setColor(const QColor& color0) override;
    void setRect(const QRectF& rect0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSGRectangleNode_access : public QSGRectangleNode
{
    jobject __qt_color_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_rect_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setColor_cref_QColor(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID color0);
    void __qt_setRect_cref_QRectF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0);
};

#endif // QSGRECTANGLENODE_SHELL_H
